@@ -125,8 +125,8 @@ class CmdUploadDeb(CmdUpload):
         package_fold = pkg_layout.package(pref)
         conanfile = self._graph_manager.load_consumer_conanfile(conanfile_path, package_fold)
         
-        assert (not conanfile.apt_user), "apt_user is not defined or empty in conanfile.py."
-        assert (not conanfile.apt_server), "apt_server is not defined or empty in conanfile.py."
+        assert (not(not conanfile.apt_user)), "apt_user is not defined or empty in conanfile.py."
+        assert (not(not conanfile.apt_server)), "apt_server is not defined or empty in conanfile.py."
         
         deb_folder = pkg_layout.deb(pref)
         deb_file = os.path.join(deb_folder, conanfile.name + "_" + conanfile.version + ".deb")
