@@ -93,11 +93,15 @@ def _create_deb_file(conanfile):
     #### set folder name
     package_name = conanfile.name
     package_version = conanfile.version
+    if not conanfile.deb_install_folder:
+        deb_install_folder = "/sense2"
+    else:
+        deb_install_folder = conanfile.deb_install_folder
     deb_folder = package_name
     deb_file = package_name + "_" + package_version + ".deb"
     debian_folder = deb_folder + "/DEBIAN"
-    app_folder = deb_folder + "/sense2"
-        
+    app_folder = deb_folder + deb_install_folder
+    
     #### generate package in build
     mkdir(debian_folder)
     mkdir(app_folder)
@@ -123,7 +127,7 @@ def _create_deb_file(conanfile):
     changelog_file = debian_folder + "/changelog"
     if os.path.exists(changelog_file):
         conanfile.run("rm " + changelog_file)
-    add_changelog_cmd = "echo " + conanfile.deb_changelog + " >> " + changelog_file
+    add_changelog_cmd = "echo " + str(conanfile.deb_changelog) + " >> " + changelog_file
     conanfile.run(add_changelog_cmd)
 
     ## add lib | bin
